@@ -1,5 +1,4 @@
 from arkitekt.schema.widgets import SearchWidget
-from PyQt5.QtWidgets import QApplication, QListWidget, QListWidgetItem, QPushButton
 from mikro_napari.helpers.stage import StageHelper
 from arkitekt.messages.postman.provide.bounced_provide import BouncedProvideMessage
 from qtpy import QtWidgets
@@ -15,17 +14,17 @@ class ArkitektWidget(QtWidgets.QWidget):
 
         self.layout = QtWidgets.QVBoxLayout(self)
 
-        self.loginButton = QPushButton("Login!")
+        self.loginButton = QtWidgets.QPushButton("Login!")
         self.loginButton.clicked.connect(self.login)
         self.layout.addWidget(self.loginButton)
 
-        self.app = QApplication.instance()
+        self.app = QtWidgets.QApplication.instance()
         self.app.lastWindowClosed.connect(self.close)
 
         self.status = QtWidgets.QLabel("Arnheim")
         self.helper = StageHelper(napari_viewer)
 
-        self.provisionsWidget = QListWidget()
+        self.provisionsWidget = QtWidgets.QListWidget()
         self.layout.addWidget(self.provisionsWidget)
 
         self.herre = HerreClient(force_sync=True, config_path=config_path, auto_login=False)
